==> colourvalues_0.2.2.tar.gz: colourvalues/inst/include/colourvalues/palettes/plasma.hpp <==
#ifndef R_COLOURVALUES_PLASMA_H
#define R_COLOURVALUES_PLASMA_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector plasma_red = {
    0.0503832136, 0.0635363639, 0.0753531234, 0.0862217979, 0.0963786097,
    0.105979704, 0.115123641, 0.123902903, 0.13238072, 0.140603076,
    0.148606527, 0.156420649, 0.164069722, 0.171573925, 0.178950212,
    0.186212958, 0.193374449, 0.20044526, 0.207434551, 0.214350298,
    0.22119675, 0.227982971, 0.234714537, 0.241396253, 0.248032377,
    0.25462669, 0.261182562, 0.267702993, 0.274190665, 0.280647969,
    0.287076059, 0.293477695, 0.299855122, 0.306209825, 0.312543124,
    0.318856183, 0.325150025, 0.331425547, 0.337683446, 0.343924591,
    0.350149699, 0.356359209, 0.362553473, 0.368732762, 0.37489727,
    0.381047116, 0.387182639, 0.39330401, 0.399410821, 0.405502914,
    0.411580082, 0.417642063, 0.423688549, 0.429719186, 0.435733575,
    0.441732123, 0.4477136, 0.453677394, 0.459622938, 0.465549631,
    0.471456847, 0.477343929, 0.483210198, 0.489054951, 0.494877466,
    0.500677687, 0.506454143, 0.512206035, 0.51793258, 0.52363299,
    0.529306474, 0.534952244, 0.54056951, 0.546157494, 0.551715423,
    0.557242538, 0.562738096, 0.568201372, 0.573631859, 0.579028682,
    0.584391137, 0.589718606, 0.595010505, 0.600266283, 0.605485428,
    0.610667469, 0.615811974, 0.620918555, 0.625986869, 0.631016615,
    0.636007543, 0.640959444, 0.645872158, 0.650745571, 0.655579615,
    0.660374266, 0.665129493, 0.669845385, 0.67452206, 0.679159664,
    0.683758384, 0.68831844, 0.692840088, 0.697323615, 0.701769334,
    0.70617759, 0.710548747, 0.714883195, 0.719181339, 0.723443604,
    0.727670428, 0.731862231, 0.736019424, 0.740142557, 0.744232102,
    0.748288533, 0.752312321, 0.756303937, 0.760263849, 0.764192516,
    0.768090391, 0.771957916, 0.775795522, 0.779603614, 0.783382636,
    0.787132978, 0.790855015, 0.794549101, 0.798215577, 0.801854758,
    0.805466945, 0.809052419, 0.812611506, 0.816144382, 0.819651255,
    0.823132309, 0.826587706, 0.830017584, 0.833422053, 0.836801237,
    0.840155276, 0.843484103, 0.846787726, 0.850066132, 0.853319279,
    0.856547103, 0.85974952, 0.862926559, 0.86607792, 0.869203436,
    0.872302917, 0.875376149, 0.878422895, 0.881442916, 0.884435982,
    0.887401682, 0.890339687, 0.893249647, 0.896131191, 0.898983931,
    0.901807455, 0.904601295, 0.907364995, 0.910098088, 0.912800095,
    0.915470518, 0.918108848, 0.920714383, 0.92328666, 0.925825146,
    0.928329275, 0.930798469, 0.93323214, 0.935629684, 0.937990034,
    0.940312939, 0.942597771, 0.944843893, 0.947050662, 0.949217427,
    0.95134353, 0.953427725, 0.95546964, 0.95746877, 0.95942443,
    0.96133593, 0.963202573, 0.965023656, 0.96679847, 0.968525639,
    0.970204593, 0.971835007, 0.973416145, 0.974947262, 0.976427606,
    0.977856416, 0.979232922, 0.980556344, 0.98182589, 0.983040742,
    0.984198924, 0.98530076, 0.986345421, 0.987332067, 0.988259846,
    0.989127893, 0.989935328, 0.990681261, 0.991364787, 0.99198499,
    0.992540939, 0.993031693, 0.993456302, 0.993813802, 0.994103226,
    0.994323596, 0.994473934, 0.99455326, 0.994560594, 0.994494964,
    0.994355411, 0.994140989, 0.993850778, 0.99348219, 0.993033251,
    0.992505214, 0.99189727, 0.99120868, 0.990438793, 0.989587065,
    0.988647741, 0.987620557, 0.986509366, 0.985314198, 0.984031139,
    0.98265282, 0.981190389, 0.979643637, 0.977994918, 0.976264977,
    0.974443038, 0.972530009, 0.970532932, 0.968443477, 0.966271225,
    0.964021057, 0.961681481, 0.959275646, 0.956808068, 0.954286813,
    0.951726083, 0.949150533, 0.94660227, 0.944151742, 0.94189612,
    0.940015097
  };

  const Rcpp::NumericVector plasma_green = {
    0.0298028976, 0.0284259729, 0.0272063728, 0.0261253206, 0.0251650976,
    0.0243092436, 0.02355625, 0.0228781011, 0.0222583774, 0.0216866674,
    0.0211535876, 0.0206507174, 0.0201705326, 0.0197063415, 0.0192522243,
    0.0188029767, 0.0183540593, 0.0179015512, 0.0174421086, 0.0169729276,
    0.0164970484, 0.0160071509, 0.0155015065, 0.0149791041, 0.0144393586,
    0.0138820918, 0.0133075156, 0.0127162163, 0.0121091423, 0.0114875915,
    0.0108554862, 0.0102128849, 0.00956079551, 0.00890185346, 0.00823900704,
    0.00757551051, 0.00691491734, 0.00626107379, 0.00561830889, 0.0049905308,
    0.00438202557, 0.00379781761, 0.00324319591, 0.00272370721, 0.00224514897,
    0.00181356205, 0.00143446923, 0.00111388259, 0.000859420809,
    0.000678091517, 0.000577101735, 0.000563847476, 0.00064590278,
    0.000831008207, 0.00112705875, 0.00153984779, 0.00207954744,
    0.00275470302, 0.00357374415, 0.00454518084, 0.00567758762, 0.00697958743,
    0.00845983494, 0.0101269996, 0.0119897486, 0.014055064, 0.0163333443,
    0.0188332232, 0.0215631918, 0.0245316468, 0.0277468735, 0.03121703,
    0.034950131, 0.0389540334, 0.0431364795, 0.0473307585, 0.0515448092,
    0.0557776706, 0.0600281369, 0.0642955547, 0.0685790261, 0.0728775875,
    0.0771902878, 0.0815161895, 0.0858543713, 0.0902039303, 0.0945639838,
    0.0989336721, 0.10331216, 0.107698641, 0.112092335, 0.116492495,
    0.120898405, 0.125309384, 0.129724785, 0.134143997, 0.138566428,
    0.14299154, 0.147418835, 0.151847851, 0.156278163, 0.160709387,
    0.165141174, 0.169573215, 0.174005236, 0.178437, 0.182868306,
    0.187298986, 0.191728906, 0.196157962, 0.200586086, 0.205013174,
    0.209439071, 0.213863965, 0.218287899, 0.222710942, 0.227133187,
    0.231554749, 0.235975765, 0.240396394, 0.244816813, 0.24923722,
    0.253657797, 0.258078397, 0.262499662, 0.266921859, 0.271345267,
    0.275770179, 0.280196901, 0.28462575, 0.289057057, 0.293491117,
    0.297927865, 0.30236813, 0.306812282, 0.311260703, 0.315713782,
    0.320171913, 0.324635499, 0.329104836, 0.333580106, 0.338062109,
    0.342551272, 0.347048028, 0.351552815, 0.356066072, 0.360588229,
    0.365119408, 0.369660446, 0.374211795, 0.37877391, 0.383347243,
    0.387932249, 0.392529339, 0.397138877, 0.401761511, 0.406397694,
    0.411047871, 0.415712489, 0.420391986, 0.425086807, 0.429797442,
    0.434524335, 0.439267908, 0.444028574, 0.448806744, 0.453602818,
    0.45841742, 0.463250828, 0.468103387, 0.472975465, 0.47786742,
    0.482779603, 0.487712357, 0.492666544, 0.497642038, 0.502639147,
    0.507658169, 0.51269939, 0.517763087, 0.522849522, 0.52795955,
    0.533093083, 0.538250172, 0.543431038, 0.54863589, 0.553864931,
    0.559118349, 0.564396327, 0.569699633, 0.57502827, 0.580382015,
    0.585761012, 0.591165394, 0.596595287, 0.602050811, 0.607532077,
    0.61303919, 0.61857225, 0.624131362, 0.629717516, 0.635329876,
    0.640968508, 0.646633475, 0.652324832, 0.65804263, 0.663786914,
    0.66955772, 0.675355082, 0.681179025, 0.687029567, 0.692906719,
    0.698810484, 0.704740854, 0.710697814, 0.716681336, 0.722691379,
    0.72872789, 0.734790799, 0.74088002, 0.746995448, 0.753136955,
    0.75930439, 0.765498551, 0.771719833, 0.777966775, 0.78423912,
    0.790536569, 0.796858775, 0.803205337, 0.809578605, 0.815977942,
    0.82240062, 0.82884598, 0.83531536, 0.84181173, 0.848328902,
    0.854866468, 0.861432314, 0.868015998, 0.874622194, 0.881250063,
    0.887896125, 0.894563989, 0.901249365, 0.907950379, 0.914672479,
    0.921406537, 0.928152065, 0.93490773, 0.941670605, 0.9484349,
    0.95518986, 0.961916487, 0.968589814, 0.975158357
  };

  const Rcpp::NumericVector plasma_blue = {
    0.527974883, 0.533123681, 0.538007001, 0.542657691, 0.547103487,
    0.551367851, 0.555467728, 0.55942348, 0.563250116, 0.566959485,
    0.570561711, 0.574065446, 0.577478074, 0.58080589, 0.584054243,
    0.587227661, 0.590329954, 0.593364304, 0.596333341, 0.599239207,
    0.602083323, 0.604867403, 0.607592438, 0.610259089, 0.612867743,
    0.615418537, 0.617911385, 0.620345997, 0.622721903, 0.625038468,
    0.627294975, 0.62949049, 0.631623923, 0.633694102, 0.635699759,
    0.637639537, 0.639512001, 0.641315649, 0.643048936, 0.644710195,
    0.646297711, 0.647809772, 0.649244641, 0.650600561, 0.651875762,
    0.653068467, 0.654176761, 0.655198755, 0.656132835, 0.656977276,
    0.65773038, 0.658390492, 0.658956004, 0.659425363, 0.659797077,
    0.660069009, 0.660240367, 0.660309966, 0.660276655, 0.660139383,
    0.65989721, 0.659549311, 0.659094989, 0.658533677, 0.657864946,
    0.657087561, 0.656202294, 0.655209222, 0.654108545, 0.652900629,
    0.65158601, 0.650165396, 0.648639668, 0.647009884, 0.645277275,
    0.64344325, 0.641509389, 0.63947744, 0.637348841, 0.635126108,
    0.632811608, 0.630407727, 0.627916992, 0.625342058, 0.622685703,
    0.619950811, 0.617140367, 0.61425744, 0.611305174, 0.608286774,
    0.605205491, 0.602064611, 0.598867442, 0.5956173, 0.592317494,
    0.588971318, 0.585582301, 0.582153572, 0.578688247, 0.575189431,
    0.571660158, 0.56810338, 0.564521958, 0.560918659, 0.557296144,
    0.55365697, 0.550003579, 0.546338299, 0.542663338, 0.538980786,
    0.535292612, 0.531600995, 0.527908434, 0.524215533, 0.520523766,
    0.516834495, 0.513148963, 0.509468305, 0.505793543, 0.502125599,
    0.49846529, 0.494813338, 0.491170517, 0.487539124, 0.483917732,
    0.480306702, 0.476706319, 0.473116798, 0.469538286, 0.465970871,
    0.46241458, 0.458869577, 0.455337565, 0.451816385, 0.448305861,
    0.444805781, 0.441315901, 0.437835947, 0.434365616, 0.430905052,
    0.427454836, 0.424013059, 0.420579333, 0.417153264, 0.413734445,
    0.410322469, 0.406916975, 0.403518809, 0.400126027, 0.396738211,
    0.393354947, 0.389975832, 0.386600468, 0.383228622, 0.379860246,
    0.376494232, 0.373130228, 0.369767893, 0.366406907, 0.363046965,
    0.359687758, 0.356328796, 0.352969777, 0.349610469, 0.346250656,
    0.342890148, 0.339528771, 0.336165582, 0.332800827, 0.329434512,
    0.32606655, 0.322696876, 0.319325444, 0.315952211, 0.31257544,
    0.309196628, 0.305815824, 0.302433101, 0.299048555, 0.295662308,
    0.292274506, 0.288883445, 0.285490391, 0.282096149, 0.27870099,
    0.275305214, 0.271909159, 0.2685132, 0.265117752, 0.261721488,
    0.258325424, 0.254931256, 0.251539615, 0.2481512, 0.244766775,
    0.241387186, 0.238013359, 0.234646316, 0.231287178, 0.227937141,
    0.224595006, 0.221264889, 0.217948456, 0.214647532, 0.211364122,
    0.208100426, 0.204858855, 0.201642049, 0.1984529, 0.195294567,
    0.1921705, 0.189084459, 0.186040537, 0.18304318, 0.180097207,
    0.177207826, 0.174380656, 0.171621733, 0.168937522, 0.166334918,
    0.163821243, 0.161404226, 0.159091984, 0.156890625, 0.154807583,
    0.152854862, 0.151041581, 0.149376885, 0.14786981, 0.146529128,
    0.145357284, 0.144362644, 0.143556679, 0.142945116, 0.142528388,
    0.142302653, 0.142278607, 0.142453425, 0.142808191, 0.143350944,
    0.144061156, 0.144922913, 0.145918663, 0.147014438, 0.148179639,
    0.149370428, 0.150520343, 0.151566019, 0.152409489, 0.152921158,
    0.152925363, 0.152177604, 0.150327944, 0.146860789, 0.140955606,
    0.131325517
  };

  const Rcpp::List plasma = Rcpp::List::create(
    Rcpp::_["r"] = plasma_red,
    Rcpp::_["g"] = plasma_green,
    Rcpp::_["b"] = plasma_blue
  );

} // namespace palette
} // namepsace colourvalues
#endif

==> colourvalues_0.3.9.tar.gz: colourvalues/inst/include/colourvalues/palettes/plasma.hpp <==
#ifndef R_COLOURVALUES_PLASMA_H
#define R_COLOURVALUES_PLASMA_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector plasma_red = {
    0.0503832136, 0.0635363639, 0.0753531234, 0.0862217979, 0.0963786097,
    0.105979704, 0.115123641, 0.123902903, 0.13238072, 0.140603076,
    0.148606527, 0.156420649, 0.164069722, 0.171573925, 0.178950212,
    0.186212958, 0.193374449, 0.20044526, 0.207434551, 0.214350298,
    0.22119675, 0.227982971, 0.234714537, 0.241396253, 0.248032377,
    0.25462669, 0.261182562, 0.267702993, 0.274190665, 0.280647969,
    0.287076059, 0.293477695, 0.299855122, 0.306209825, 0.312543124,
    0.318856183, 0.325150025, 0.331425547, 0.337683446, 0.343924591,
    0.350149699, 0.356359209, 0.362553473, 0.368732762, 0.37489727,
    0.381047116, 0.387182639, 0.39330401, 0.399410821, 0.405502914,
    0.411580082, 0.417642063, 0.423688549, 0.429719186, 0.435733575,
    0.441732123, 0.4477136, 0.453677394, 0.459622938, 0.465549631,
    0.471456847, 0.477343929, 0.483210198, 0.489054951, 0.494877466,
    0.500677687, 0.506454143, 0.512206035, 0.51793258, 0.52363299,
    0.529306474, 0.534952244, 0.54056951, 0.546157494, 0.551715423,
    0.557242538, 0.562738096, 0.568201372, 0.573631859, 0.579028682,
    0.584391137, 0.589718606, 0.595010505, 0.600266283, 0.605485428,
    0.610667469, 0.615811974, 0.620918555, 0.625986869, 0.631016615,
    0.636007543, 0.640959444, 0.645872158, 0.650745571, 0.655579615,
    0.660374266, 0.665129493, 0.669845385, 0.67452206, 0.679159664,
    0.683758384, 0.68831844, 0.692840088, 0.697323615, 0.701769334,
    0.70617759, 0.710548747, 0.714883195, 0.719181339, 0.723443604,
    0.727670428, 0.731862231, 0.736019424, 0.740142557, 0.744232102,
    0.748288533, 0.752312321, 0.756303937, 0.760263849, 0.764192516,
    0.768090391, 0.771957916, 0.775795522, 0.779603614, 0.783382636,
    0.787132978, 0.790855015, 0.794549101, 0.798215577, 0.801854758,
    0.805466945, 0.809052419, 0.812611506, 0.816144382, 0.819651255,
    0.823132309, 0.826587706, 0.830017584, 0.833422053, 0.836801237,
    0.840155276, 0.843484103, 0.846787726, 0.850066132, 0.853319279,
    0.856547103, 0.85974952, 0.862926559, 0.86607792, 0.869203436,
    0.872302917, 0.875376149, 0.878422895, 0.881442916, 0.884435982,
    0.887401682, 0.890339687, 0.893249647, 0.896131191, 0.898983931,
    0.901807455, 0.904601295, 0.907364995, 0.910098088, 0.912800095,
    0.915470518, 0.918108848, 0.920714383, 0.92328666, 0.925825146,
    0.928329275, 0.930798469, 0.93323214, 0.935629684, 0.937990034,
    0.940312939, 0.942597771, 0.944843893, 0.947050662, 0.949217427,
    0.95134353, 0.953427725, 0.95546964, 0.95746877, 0.95942443,
    0.96133593, 0.963202573, 0.965023656, 0.96679847, 0.968525639,
    0.970204593, 0.971835007, 0.973416145, 0.974947262, 0.976427606,
    0.977856416, 0.979232922, 0.980556344, 0.98182589, 0.983040742,
    0.984198924, 0.98530076, 0.986345421, 0.987332067, 0.988259846,
    0.989127893, 0.989935328, 0.990681261, 0.991364787, 0.99198499,
    0.992540939, 0.993031693, 0.993456302, 0.993813802, 0.994103226,
    0.994323596, 0.994473934, 0.99455326, 0.994560594, 0.994494964,
    0.994355411, 0.994140989, 0.993850778, 0.99348219, 0.993033251,
    0.992505214, 0.99189727, 0.99120868, 0.990438793, 0.989587065,
    0.988647741, 0.987620557, 0.986509366, 0.985314198, 0.984031139,
    0.98265282, 0.981190389, 0.979643637, 0.977994918, 0.976264977,
    0.974443038, 0.972530009, 0.970532932, 0.968443477, 0.966271225,
    0.964021057, 0.961681481, 0.959275646, 0.956808068, 0.954286813,
    0.951726083, 0.949150533, 0.94660227, 0.944151742, 0.94189612,
    0.940015097
  };

  const Rcpp::NumericVector plasma_green = {
    0.0298028976, 0.0284259729, 0.0272063728, 0.0261253206, 0.0251650976,
    0.0243092436, 0.02355625, 0.0228781011, 0.0222583774, 0.0216866674,
    0.0211535876, 0.0206507174, 0.0201705326, 0.0197063415, 0.0192522243,
    0.0188029767, 0.0183540593, 0.0179015512, 0.0174421086, 0.0169729276,
    0.0164970484, 0.0160071509, 0.0155015065, 0.0149791041, 0.0144393586,
    0.0138820918, 0.0133075156, 0.0127162163, 0.0121091423, 0.0114875915,
    0.0108554862, 0.0102128849, 0.00956079551, 0.00890185346, 0.00823900704,
    0.00757551051, 0.00691491734, 0.00626107379, 0.00561830889, 0.0049905308,
    0.00438202557, 0.00379781761, 0.00324319591, 0.00272370721, 0.00224514897,
    0.00181356205, 0.00143446923, 0.00111388259, 0.000859420809,
    0.000678091517, 0.000577101735, 0.000563847476, 0.00064590278,
    0.000831008207, 0.00112705875, 0.00153984779, 0.00207954744,
    0.00275470302, 0.00357374415, 0.00454518084, 0.00567758762, 0.00697958743,
    0.00845983494, 0.0101269996, 0.0119897486, 0.014055064, 0.0163333443,
    0.0188332232, 0.0215631918, 0.0245316468, 0.0277468735, 0.03121703,
    0.034950131, 0.0389540334, 0.0431364795, 0.0473307585, 0.0515448092,
    0.0557776706, 0.0600281369, 0.0642955547, 0.0685790261, 0.0728775875,
    0.0771902878, 0.0815161895, 0.0858543713, 0.0902039303, 0.0945639838,
    0.0989336721, 0.10331216, 0.107698641, 0.112092335, 0.116492495,
    0.120898405, 0.125309384, 0.129724785, 0.134143997, 0.138566428,
    0.14299154, 0.147418835, 0.151847851, 0.156278163, 0.160709387,
    0.165141174, 0.169573215, 0.174005236, 0.178437, 0.182868306,
    0.187298986, 0.191728906, 0.196157962, 0.200586086, 0.205013174,
    0.209439071, 0.213863965, 0.218287899, 0.222710942, 0.227133187,
    0.231554749, 0.235975765, 0.240396394, 0.244816813, 0.24923722,
    0.253657797, 0.258078397, 0.262499662, 0.266921859, 0.271345267,
    0.275770179, 0.280196901, 0.28462575, 0.289057057, 0.293491117,
    0.297927865, 0.30236813, 0.306812282, 0.311260703, 0.315713782,
    0.320171913, 0.324635499, 0.329104836, 0.333580106, 0.338062109,
    0.342551272, 0.347048028, 0.351552815, 0.356066072, 0.360588229,
    0.365119408, 0.369660446, 0.374211795, 0.37877391, 0.383347243,
    0.387932249, 0.392529339, 0.397138877, 0.401761511, 0.406397694,
    0.411047871, 0.415712489, 0.420391986, 0.425086807, 0.429797442,
    0.434524335, 0.439267908, 0.444028574, 0.448806744, 0.453602818,
    0.45841742, 0.463250828, 0.468103387, 0.472975465, 0.47786742,
    0.482779603, 0.487712357, 0.492666544, 0.497642038, 0.502639147,
    0.507658169, 0.51269939, 0.517763087, 0.522849522, 0.52795955,
    0.533093083, 0.538250172, 0.543431038, 0.54863589, 0.553864931,
    0.559118349, 0.564396327, 0.569699633, 0.57502827, 0.580382015,
    0.585761012, 0.591165394, 0.596595287, 0.602050811, 0.607532077,
    0.61303919, 0.61857225, 0.624131362, 0.629717516, 0.635329876,
    0.640968508, 0.646633475, 0.652324832, 0.65804263, 0.663786914,
    0.66955772, 0.675355082, 0.681179025, 0.687029567, 0.692906719,
    0.698810484, 0.704740854, 0.710697814, 0.716681336, 0.722691379,
    0.72872789, 0.734790799, 0.74088002, 0.746995448, 0.753136955,
    0.75930439, 0.765498551, 0.771719833, 0.777966775, 0.78423912,
    0.790536569, 0.796858775, 0.803205337, 0.809578605, 0.815977942,
    0.82240062, 0.82884598, 0.83531536, 0.84181173, 0.848328902,
    0.854866468, 0.861432314, 0.868015998, 0.874622194, 0.881250063,
    0.887896125, 0.894563989, 0.901249365, 0.907950379, 0.914672479,
    0.921406537, 0.928152065, 0.93490773, 0.941670605, 0.9484349,
    0.95518986, 0.961916487, 0.968589814, 0.975158357
  };

  const Rcpp::NumericVector plasma_blue = {
    0.527974883, 0.533123681, 0.538007001, 0.542657691, 0.547103487,
    0.551367851, 0.555467728, 0.55942348, 0.563250116, 0.566959485,
    0.570561711, 0.574065446, 0.577478074, 0.58080589, 0.584054243,
    0.587227661, 0.590329954, 0.593364304, 0.596333341, 0.599239207,
    0.602083323, 0.604867403, 0.607592438, 0.610259089, 0.612867743,
    0.615418537, 0.617911385, 0.620345997, 0.622721903, 0.625038468,
    0.627294975, 0.62949049, 0.631623923, 0.633694102, 0.635699759,
    0.637639537, 0.639512001, 0.641315649, 0.643048936, 0.644710195,
    0.646297711, 0.647809772, 0.649244641, 0.650600561, 0.651875762,
    0.653068467, 0.654176761, 0.655198755, 0.656132835, 0.656977276,
    0.65773038, 0.658390492, 0.658956004, 0.659425363, 0.659797077,
    0.660069009, 0.660240367, 0.660309966, 0.660276655, 0.660139383,
    0.65989721, 0.659549311, 0.659094989, 0.658533677, 0.657864946,
    0.657087561, 0.656202294, 0.655209222, 0.654108545, 0.652900629,
    0.65158601, 0.650165396, 0.648639668, 0.647009884, 0.645277275,
    0.64344325, 0.641509389, 0.63947744, 0.637348841, 0.635126108,
    0.632811608, 0.630407727, 0.627916992, 0.625342058, 0.622685703,
    0.619950811, 0.617140367, 0.61425744, 0.611305174, 0.608286774,
    0.605205491, 0.602064611, 0.598867442, 0.5956173, 0.592317494,
    0.588971318, 0.585582301, 0.582153572, 0.578688247, 0.575189431,
    0.571660158, 0.56810338, 0.564521958, 0.560918659, 0.557296144,
    0.55365697, 0.550003579, 0.546338299, 0.542663338, 0.538980786,
    0.535292612, 0.531600995, 0.527908434, 0.524215533, 0.520523766,
    0.516834495, 0.513148963, 0.509468305, 0.505793543, 0.502125599,
    0.49846529, 0.494813338, 0.491170517, 0.487539124, 0.483917732,
    0.480306702, 0.476706319, 0.473116798, 0.469538286, 0.465970871,
    0.46241458, 0.458869577, 0.455337565, 0.451816385, 0.448305861,
    0.444805781, 0.441315901, 0.437835947, 0.434365616, 0.430905052,
    0.427454836, 0.424013059, 0.420579333, 0.417153264, 0.413734445,
    0.410322469, 0.406916975, 0.403518809, 0.400126027, 0.396738211,
    0.393354947, 0.389975832, 0.386600468, 0.383228622, 0.379860246,
    0.376494232, 0.373130228, 0.369767893, 0.366406907, 0.363046965,
    0.359687758, 0.356328796, 0.352969777, 0.349610469, 0.346250656,
    0.342890148, 0.339528771, 0.336165582, 0.332800827, 0.329434512,
    0.32606655, 0.322696876, 0.319325444, 0.315952211, 0.31257544,
    0.309196628, 0.305815824, 0.302433101, 0.299048555, 0.295662308,
    0.292274506, 0.288883445, 0.285490391, 0.282096149, 0.27870099,
    0.275305214, 0.271909159, 0.2685132, 0.265117752, 0.261721488,
    0.258325424, 0.254931256, 0.251539615, 0.2481512, 0.244766775,
    0.241387186, 0.238013359, 0.234646316, 0.231287178, 0.227937141,
    0.224595006, 0.221264889, 0.217948456, 0.214647532, 0.211364122,
    0.208100426, 0.204858855, 0.201642049, 0.1984529, 0.195294567,
    0.1921705, 0.189084459, 0.186040537, 0.18304318, 0.180097207,
    0.177207826, 0.174380656, 0.171621733, 0.168937522, 0.166334918,
    0.163821243, 0.161404226, 0.159091984, 0.156890625, 0.154807583,
    0.152854862, 0.151041581, 0.149376885, 0.14786981, 0.146529128,
    0.145357284, 0.144362644, 0.143556679, 0.142945116, 0.142528388,
    0.142302653, 0.142278607, 0.142453425, 0.142808191, 0.143350944,
    0.144061156, 0.144922913, 0.145918663, 0.147014438, 0.148179639,
    0.149370428, 0.150520343, 0.151566019, 0.152409489, 0.152921158,
    0.152925363, 0.152177604, 0.150327944, 0.146860789, 0.140955606,
    0.131325517
  };

  // const Rcpp::List plasma = Rcpp::List::create(
  //   Rcpp::_["r"] = plasma_red,
  //   Rcpp::_["g"] = plasma_green,
  //   Rcpp::_["b"] = plasma_blue
  // );

} // namespace palette
} // namepsace colourvalues
#endif
